package com.qmth.distributed.print.api;

import com.alibaba.fastjson.JSONArray;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.distributed.print.business.bean.dto.obe.CourseRequirementMatrixDto;
import com.qmth.distributed.print.business.bean.dto.report.ObeCourseRequirementDto;
import com.qmth.distributed.print.business.bean.dto.report.ObeSubRequirementsDto;
import com.qmth.distributed.print.business.bean.result.ObeCourseRequirementListResult;
import com.qmth.distributed.print.business.bean.result.ScoreResult;
import com.qmth.distributed.print.business.entity.ObeCourseOutline;
import com.qmth.distributed.print.business.entity.ObeCourseRequirementReport;
import com.qmth.distributed.print.business.service.ObeCourseOutlineService;
import com.qmth.distributed.print.business.service.ObeCourseRequirementMatrixService;
import com.qmth.distributed.print.business.service.ObeCourseRequirementReportService;
import com.qmth.distributed.print.business.service.TRExamStudentService;
import com.qmth.teachcloud.common.contant.SystemConstant;
import com.qmth.teachcloud.common.util.JacksonUtil;
import com.qmth.teachcloud.common.util.Result;
import com.qmth.teachcloud.common.util.ResultUtil;
import io.swagger.annotations.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import java.util.*;

/**
 * <p>
 * obe专业达成度报表 前端控制器
 * </p>
 *
 * @author wangliang
 * @since 2024-02-18
 */
@Api(tags = "obe专业达成度报表Controller")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + SystemConstant.PREFIX_URL_OBE)
public class ObeReportController {
    private final static Logger log = LoggerFactory.getLogger(ObeReportController.class);

    @Resource
    ObeCourseRequirementReportService obeCourseRequirementReportService;

    @Resource
    TRExamStudentService trExamStudentService;

    @Resource
    ObeCourseRequirementMatrixService obeCourseRequirementMatrixService;

    @Resource
    ObeCourseOutlineService obeCourseOutlineService;

    @ApiOperation(value = "毕业要求达成度报表列表")
    @RequestMapping(value = "/requirements/list", method = RequestMethod.POST)
    @ApiResponses({@ApiResponse(code = 200, message = "分页查询", response = ObeCourseRequirementListResult.class)})
    public Result requirementsList(@ApiParam(value = "专业ID", required = true) @RequestParam Long professionalId,
                                   @ApiParam(value = "培养方案名称") @RequestParam(required = false) String cultureProgramName,
                                   @ApiParam(value = "分页页码", required = true) @RequestParam @Min(SystemConstant.PAGE_NUMBER_MIN) Integer pageNumber,
                                   @ApiParam(value = "分页数", required = true) @RequestParam @Min(SystemConstant.PAGE_SIZE_MIN) @Max(SystemConstant.PAGE_SIZE_MAX) Integer pageSize) {
        return ResultUtil.ok(obeCourseRequirementReportService.obeCourseRequirementReportList(new Page<>(pageNumber, pageSize), professionalId, cultureProgramName));
    }

    @ApiOperation(value = "毕业要求达成度雷达报表")
    @RequestMapping(value = "/requirements/radar/report", method = RequestMethod.POST)
    @ApiResponses({@ApiResponse(code = 200, message = "毕业要求达成度雷达报表", response = ScoreResult.class)})
    @Transactional
    public Result requirementsRadarReport(@ApiParam(value = "培养方案ID", required = true) @RequestParam Long cultureProgramId) {
        List<CourseRequirementMatrixDto> courseRequirementMatrixDtoList = obeCourseRequirementMatrixService.getMatrix(cultureProgramId);
        ObeCourseRequirementDto obeCourseRequirementResultDto = null;
        if (!CollectionUtils.isEmpty(courseRequirementMatrixDtoList)) {
            log.info("courseRequirementMatrixDto:{}", JacksonUtil.parseJson(courseRequirementMatrixDtoList));
            List<ObeCourseOutline> obeCourseOutlineList = obeCourseOutlineService.findByCultureProgramId(cultureProgramId);
            if (!CollectionUtils.isEmpty(obeCourseOutlineList)) {
                List<ObeCourseRequirementDto> obeCourseRequirementDtoList = new ArrayList<>();
                Map<Long, List<ObeSubRequirementsDto>> obeSubRequirementsDtoMap = new LinkedHashMap<>();
                for (ObeCourseOutline obeCourseOutline : obeCourseOutlineList) {
                    obeCourseRequirementReportService.matrixCourseReportInfo(courseRequirementMatrixDtoList, obeCourseOutline.getId(),
                            null, obeCourseRequirementDtoList, obeSubRequirementsDtoMap);
                }
                obeCourseRequirementResultDto = obeCourseRequirementReportService.matrixCourseReport(obeCourseRequirementDtoList, obeSubRequirementsDtoMap);

                ObeCourseRequirementReport obeCourseRequirementReport = new ObeCourseRequirementReport(
                        cultureProgramId, Objects.nonNull(obeCourseRequirementResultDto) ? JacksonUtil.parseJson(obeCourseRequirementResultDto) : null,
                        !CollectionUtils.isEmpty(obeCourseRequirementDtoList) ? JacksonUtil.parseJson(obeCourseRequirementDtoList) : null, Objects.nonNull(obeCourseRequirementResultDto) && Objects.nonNull(obeCourseRequirementResultDto.getMatrixDegree()) ? obeCourseRequirementResultDto.getMatrixDegree().doubleValue() : null);
                obeCourseRequirementReportService.removeReport(cultureProgramId);
                if (Objects.nonNull(obeCourseRequirementReport.getRequirementRadar()) &&
                        Objects.nonNull(obeCourseRequirementReport.getRequirementDetail())
                        && Objects.nonNull(obeCourseRequirementReport.getRequirementDegree())) {
                    obeCourseRequirementReportService.save(obeCourseRequirementReport);
                }
            }
        }
        return ResultUtil.ok(obeCourseRequirementResultDto);
    }

    @ApiOperation(value = "毕业要求达成度详情报表")
    @RequestMapping(value = "/requirements/detail/report", method = RequestMethod.POST)
    @ApiResponses({@ApiResponse(code = 200, message = "毕业要求达成度详情报表", response = ScoreResult.class)})
    public Result requirementsDetailReport(@ApiParam(value = "培养方案ID", required = true) @RequestParam Long cultureProgramId) {
        ObeCourseRequirementReport obeCourseRequirementReport = obeCourseRequirementReportService.findByCultureProgramId(cultureProgramId);
        List<ObeCourseRequirementDto> obeCourseRequirementDtoList = new ArrayList<>();
        if (Objects.nonNull(obeCourseRequirementReport) && Objects.nonNull(obeCourseRequirementReport.getRequirementDetail())) {
            obeCourseRequirementDtoList = JSONArray.parseArray(obeCourseRequirementReport.getRequirementDetail(), ObeCourseRequirementDto.class);
        } else {
            List<CourseRequirementMatrixDto> courseRequirementMatrixDtoList = obeCourseRequirementMatrixService.getMatrix(cultureProgramId);
            if (!CollectionUtils.isEmpty(courseRequirementMatrixDtoList)) {
                log.info("courseRequirementMatrixDto:{}", JacksonUtil.parseJson(courseRequirementMatrixDtoList));
                List<ObeCourseOutline> obeCourseOutlineList = obeCourseOutlineService.findByCultureProgramId(cultureProgramId);
                if (!CollectionUtils.isEmpty(obeCourseOutlineList)) {
                    Map<Long, List<ObeSubRequirementsDto>> obeSubRequirementsDtoMap = new LinkedHashMap<>();
                    for (ObeCourseOutline obeCourseOutline : obeCourseOutlineList) {
                        obeCourseRequirementReportService.matrixCourseReportInfo(courseRequirementMatrixDtoList, obeCourseOutline.getId(),
                                null, obeCourseRequirementDtoList, obeSubRequirementsDtoMap);
                    }
                }
            }
        }
        return ResultUtil.ok(obeCourseRequirementDtoList);
    }

    @ApiOperation(value = "毕业要求达成度学生报表-列表")
    @RequestMapping(value = "/student_requirement/page", method = RequestMethod.POST)
    @ApiResponses({@ApiResponse(code = 200, message = "毕业要求达成度学生报表", response = ScoreResult.class)})
    public Result requirementsStudentPage(@ApiParam(value = "培养方案ID") @RequestParam(required = false) Long cultureProgramId,
                                          @ApiParam(value = "学号/姓名") @RequestParam(required = false) String studentCodeOrName,
                                          @RequestParam @Min(SystemConstant.PAGE_NUMBER_MIN) Integer pageNumber,
                                          @RequestParam @Min(SystemConstant.PAGE_SIZE_MIN) @Max(SystemConstant.PAGE_SIZE_MAX) Integer pageSize) {
        return ResultUtil.ok(trExamStudentService.getRequirementsStudentPage(cultureProgramId, studentCodeOrName, pageNumber, pageSize));
    }

    @ApiOperation(value = "毕业要求达成度学生报表-查看详情")
    @RequestMapping(value = "/student_requirement/detail", method = RequestMethod.POST)
    @ApiResponses({@ApiResponse(code = 200, message = "毕业要求达成度学生报表", response = ScoreResult.class)})
    public Result requirementsStudentReport(@ApiParam(value = "培养方案ID", required = true) @RequestParam Long cultureProgramId,
                                            @ApiParam(value = "学号", required = true) @RequestParam String studentCode,
                                            @ApiParam(value = "学期") @RequestParam(required = false) Long semesterId) {
        return ResultUtil.ok(trExamStudentService.getRequirementsStudentReport(cultureProgramId, studentCode, semesterId));
    }
}
